:orphan:

Tutorials!
==========

More tutorials are on the way! In the meantime, check out the EEG2025 Competition lessons and our EEGDash basics guide.



.. raw:: html

    <div class="sphx-glr-thumbnails">

.. thumbnail-parent-div-open

.. thumbnail-parent-div-close

.. raw:: html

    </div>

EEG Dash
========

Playing with eegdash!


.. raw:: html

    <div class="sphx-glr-thumbnails">

.. thumbnail-parent-div-open

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="EEGDash example for eyes open vs. closed classification.">

.. only:: html

  .. image:: /generated/auto_examples/core/images/thumb/sphx_glr_tutorial_eoec_thumb.png
    :alt:

  :ref:`sphx_glr_generated_auto_examples_core_tutorial_eoec.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Eyes Open vs. Closed Classification</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="EEGDash example for eyes open vs. closed classification.">

.. only:: html

  .. image:: /generated/auto_examples/core/images/thumb/sphx_glr_tutorial_feature_extractor_open_close_eye_thumb.png
    :alt:

  :ref:`sphx_glr_generated_auto_examples_core_tutorial_feature_extractor_open_close_eye.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">EEGDash Feature Extractor</div>
    </div>


.. thumbnail-parent-div-close

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /generated/auto_examples/core/tutorial_eoec
   /generated/auto_examples/core/tutorial_feature_extractor_open_close_eye

EEG 2025 Foundation Challenge 
=============================

1. Cross-Task Transfer Learning: Developing models that can effectively transfer knowledge from passive EEG tasks to active tasks
2. Subject Invariant Representation: Creating robust representations that generalize across different subjects while predicting clinical factors



.. raw:: html

    <div class="sphx-glr-thumbnails">

.. thumbnail-parent-div-open

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Challenge 1: Cross-Task Transfer Learning!">

.. only:: html

  .. image:: /generated/auto_examples/eeg2025/images/thumb/sphx_glr_tutorial_challenge_1_thumb.png
    :alt:

  :ref:`sphx_glr_generated_auto_examples_eeg2025_tutorial_challenge_1.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Challenge 1: Cross-Task Transfer Learning!</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Challenge 2: Predicting the p-factor from EEG">

.. only:: html

  .. image:: /generated/auto_examples/eeg2025/images/thumb/sphx_glr_tutorial_challenge_2_thumb.png
    :alt:

  :ref:`sphx_glr_generated_auto_examples_eeg2025_tutorial_challenge_2.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Challenge 2: Predicting the p-factor from EEG</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Many HPC clusters restrict or block network access. It&#x27;s common to have dedicated queues for internet-enabled jobs that differ from GPU queues. This tutorial shows how to use /api/dataset/eegdash.dataset.EEGChallengeDataset offline once a dataset is present on disk.">

.. only:: html

  .. image:: /generated/auto_examples/eeg2025/images/thumb/sphx_glr_tutorial_eegdash_offline_thumb.png
    :alt:

  :ref:`sphx_glr_generated_auto_examples_eeg2025_tutorial_eegdash_offline.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Working Offline with EEGDash</div>
    </div>


.. thumbnail-parent-div-close

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /generated/auto_examples/eeg2025/tutorial_challenge_1
   /generated/auto_examples/eeg2025/tutorial_challenge_2
   /generated/auto_examples/eeg2025/tutorial_eegdash_offline


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: auto_examples_python.zip </generated/auto_examples/auto_examples_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </generated/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
